@@ -39,6 +39,7 @@ G_DEFINE_TYPE(GVirConfigDomain, gvir_config_domain, GVIR_CONFIG_TYPE_OBJECT);
 enum {
     PROP_0,
     PROP_NAME,
+    PROP_UUID,
     PROP_TITLE,
     PROP_DESCRIPTION,
     PROP_MEMORY,
@@ -58,6 +59,9 @@ static void gvir_config_domain_get_property(GObject *object,
     case PROP_NAME:
         g_value_set_string(value, gvir_config_domain_get_name(domain));
         break;
+    case PROP_UUID:
+        g_value_set_string(value, gvir_config_domain_get_uuid(domain));
+        break;
     case PROP_TITLE:
         g_value_set_string(value, gvir_config_domain_get_title(domain));
         break;
@@ -93,6 +97,9 @@ static void gvir_config_domain_set_property(GObject *object,
     case PROP_NAME:
         gvir_config_domain_set_name(domain, g_value_get_string(value));
         break;
+    case PROP_UUID:
+        gvir_config_domain_set_uuid(domain, g_value_get_string(value));
+        break;
     case PROP_TITLE:
         gvir_config_domain_set_title(domain, g_value_get_string(value));
         break;
@@ -134,6 +141,14 @@ static void gvir_config_domain_class_init(GVirConfigDomainClass *klass)
                                                         NULL,
                                                         G_PARAM_READWRITE |
                                                         G_PARAM_STATIC_STRINGS));
+    g_object_class_install_property(object_class,
+                                    PROP_UUID,
+                                    g_param_spec_string("uuid",
+                                                        "UUID",
+                                                        "Domain UUID",
+                                                        NULL,
+                                                        G_PARAM_READWRITE |
+                                                        G_PARAM_STATIC_STRINGS));
     g_object_class_install_property(object_class,
                                     PROP_TITLE,
                                     g_param_spec_string("title",
@@ -188,11 +203,11 @@ static void gvir_config_domain_class_init(GVirConfigDomainClass *klass)
 }
 
 
-static void gvir_config_domain_init(GVirConfigDomain *conn)
+static void gvir_config_domain_init(GVirConfigDomain *domain)
 {
-    g_debug("Init GVirConfigDomain=%p", conn);
+    g_debug("Init GVirConfigDomain=%p", domain);
 
-    conn->priv = GVIR_CONFIG_DOMAIN_GET_PRIVATE(conn);
+    domain->priv = GVIR_CONFIG_DOMAIN_GET_PRIVATE(domain);
 }
 
 
@@ -247,6 +262,12 @@ const char *gvir_config_domain_get_name(GVirConfigDomain *domain)
                                                "name");
 }
 
+const char *gvir_config_domain_get_uuid(GVirConfigDomain *domain)
+{
+    return gvir_config_object_get_node_content(GVIR_CONFIG_OBJECT(domain),
+                                               "uuid");
+}
+
 const char *gvir_config_domain_get_title(GVirConfigDomain *domain)
 {
     return gvir_config_object_get_node_content(GVIR_CONFIG_OBJECT(domain),
@@ -265,6 +286,18 @@ void gvir_config_domain_set_name(GVirConfigDomain *domain, const char *name)
     g_object_notify(G_OBJECT(domain), "name");
 }
 
+/**
+ * gvir_config_domain_set_uuid:
+ * @domain: a #GVirConfigDomain
+ * @uuid: (allow-none):
+ */
+void gvir_config_domain_set_uuid(GVirConfigDomain *domain, const char *uuid)
+{
+    gvir_config_object_set_node_content(GVIR_CONFIG_OBJECT(domain),
+                                        "uuid", uuid);
+    g_object_notify(G_OBJECT(domain), "uuid");
+}
+
 /**
  * gvir_config_domain_set_title:
  * @domain: a #GVirConfigDomain
@@ -414,6 +447,7 @@ void gvir_config_domain_set_memory(GVirConfigDomain *domain, guint64 memory)
     gvir_config_object_set_attribute(GVIR_CONFIG_OBJECT(node),
                                      "unit", "KiB",
                                      NULL);
+    g_object_unref(G_OBJECT(node));
     g_object_notify(G_OBJECT(domain), "memory");
 }
 
@@ -439,6 +473,7 @@ void gvir_config_domain_set_current_memory(GVirConfigDomain *domain,
     gvir_config_object_set_attribute(GVIR_CONFIG_OBJECT(node),
                                      "unit", "KiB",
                                      NULL);
+    g_object_unref(G_OBJECT(node));
     g_object_notify(G_OBJECT(domain), "current-memory");
 }
 
@@ -508,6 +543,30 @@ void gvir_config_domain_set_features(GVirConfigDomain *domain,
     g_object_notify(G_OBJECT(domain), "features");
 }
 
+
+/**
+ * gvir_config_domain_get_clock:
+ * @domain: a #GVirConfigDomain
+ *
+ * Gets the clock configuration of @domain
+ *
+ * Returns: (transfer full): A #GVirConfigDomainClock. The returned
+ * object should be unreffed with g_object_unref() when no longer needed.
+ */
+GVirConfigDomainClock *gvir_config_domain_get_clock(GVirConfigDomain *domain)
+{
+    GVirConfigObject *object;
+
+    g_return_val_if_fail(GVIR_CONFIG_IS_DOMAIN(domain), NULL);
+
+    object = gvir_config_object_get_child_with_type(GVIR_CONFIG_OBJECT(domain),
+                                                    "clock",
+                                                    GVIR_CONFIG_TYPE_DOMAIN_CLOCK);
+
+    return GVIR_CONFIG_DOMAIN_CLOCK(object);
+}
+
+
 /**
  * gvir_config_domain_set_clock:
  * @domain: a #GVirConfigDomain
@@ -517,7 +576,7 @@ void gvir_config_domain_set_clock(GVirConfigDomain *domain,
                                   GVirConfigDomainClock *klock)
 {
     g_return_if_fail(GVIR_CONFIG_IS_DOMAIN(domain));
-    g_return_if_fail(klock != NULL || GVIR_CONFIG_IS_DOMAIN_CLOCK(klock));
+    g_return_if_fail(klock == NULL || GVIR_CONFIG_IS_DOMAIN_CLOCK(klock));
 
     gvir_config_object_attach_replace(GVIR_CONFIG_OBJECT(domain),
                                       "clock",
@@ -798,7 +857,7 @@ void gvir_config_domain_set_cpu(GVirConfigDomain *domain,
                                 GVirConfigDomainCpu *cpu)
 {
     g_return_if_fail(GVIR_CONFIG_IS_DOMAIN(domain));
-    g_return_if_fail(cpu != NULL || GVIR_CONFIG_IS_DOMAIN_CPU(cpu));
+    g_return_if_fail(cpu == NULL || GVIR_CONFIG_IS_DOMAIN_CPU(cpu));
 
     gvir_config_object_attach_replace(GVIR_CONFIG_OBJECT(domain),
                                       "cpu",
